@@ -8,7 +8,7 @@
  *
  *   The license which is distributed with this software in the file COPYRIGHT
  *   applies to this software. If your distribution is missing this file, you
- *   may request it from <pekkas@netcore.fi>.
+ *   may request it from <reubenhwk@gmail.com>.
  *
  */
 
@@ -26,7 +26,7 @@ static uint8_t ll_prefix[] = { 0xfe, 0x80 };
  * the defined prefixes
  */
 int
-setup_deviceinfo(struct Interface *iface)
+update_device_info(struct Interface *iface)
 {
 	struct ifaddrs *addresses = 0, *ifa;
 
