@@ -8,7 +8,7 @@
  *
  *   The license which is distributed with this software in the file COPYRIGHT
  *   applies to this software. If your distribution is missing this file, you
- *   may request it from <pekkas@netcore.fi>.
+ *   may request it from <reubenhwk@gmail.com>.
  *
  */
 
@@ -39,6 +39,7 @@ check_device(struct Interface *iface)
                 	flog(LOG_ERR, "interface %s is not UP", iface->Name);
 		return (-1);
 	}
+
 	if (!(ifr.ifr_flags & IFF_RUNNING))
 	{
 		if (!iface->IgnoreIfMissing)
@@ -46,18 +47,10 @@ check_device(struct Interface *iface)
 		return (-1);
 	}
 
-	if (! iface->UnicastOnly && !(ifr.ifr_flags & IFF_MULTICAST))
+	if (!iface->UnicastOnly && !(ifr.ifr_flags & IFF_MULTICAST))
 	{
-		flog(LOG_WARNING, "interface %s does not support multicast",
-			iface->Name);
-		flog(LOG_WARNING, "   do you need to add the UnicastOnly flag?");
-	}
-
-	if (! iface->UnicastOnly && !(ifr.ifr_flags & IFF_BROADCAST))
-	{
-		flog(LOG_WARNING, "interface %s does not support broadcast",
-			iface->Name);
-		flog(LOG_WARNING, "   do you need to add the UnicastOnly flag?");
+		flog(LOG_INFO, "interface %s does not support multicast, forcing UnicastOnly", iface->Name);
+		iface->UnicastOnly = 1;
 	}
 
 	return 0;
