@@ -9,7 +9,7 @@
  *
  *   The license which is distributed with this software in the file COPYRIGHT
  *   applies to this software. If your distribution is missing this file, you
- *   may request it from <pekkas@netcore.fi>.
+ *   may request it from <reubenhwk@gmail.com>.
  *
  */
 
@@ -21,10 +21,12 @@
 #include "defaults.h"
 #include "log.h"
 
-#define CONTACT_EMAIL	"Pekka Savola <pekkas@netcore.fi>"
+#define CONTACT_EMAIL	"Reuben Hawkins <reubenhwk@gmail.com>"
 
 extern int sock;
 
+extern int disableigmp6check;
+
 #define min(a,b)	(((a) < (b)) ? (a) : (b))
 
 struct AdvPrefix;
@@ -195,7 +197,7 @@ int next_time_msec(struct Interface const * iface);
 int expired(struct Interface const * iface);
 
 /* device.c */
-int setup_deviceinfo(struct Interface *);
+int update_device_info(struct Interface *);
 int check_device(struct Interface *);
 int setup_linklocal_addr(struct Interface *);
 int setup_allrouters_membership(struct Interface *);
@@ -221,6 +223,12 @@ int open_icmpv6_socket(void);
 /* send.c */
 int send_ra(struct Interface *iface, struct in6_addr *dest);
 int send_ra_forall(struct Interface *iface, struct in6_addr *dest);
+int really_send(
+		struct in6_addr const *dest,
+		unsigned int if_index,
+		struct in6_addr if_addr,
+		unsigned char * buff,
+		size_t len);
 
 /* process.c */
 void process(struct Interface *, unsigned char *, int,
