@@ -9,7 +9,7 @@
  *
  *   The license which is distributed with this software in the file COPYRIGHT
  *   applies to this software. If your distribution is missing this file, you
- *   may request it from <pekkas@netcore.fi>.
+ *   may request it from <reubenhwk@gmail.com>.
  *
  */
 
@@ -387,9 +387,16 @@ print_ff(unsigned char *msg, int len, struct sockaddr_in6 *addr, int hoplimit, u
 		case ND_OPT_ROUTE_INFORMATION:
 			rinfo = (struct nd_opt_route_info_local *) opt_str;
 
-			print_addr(&rinfo->nd_opt_ri_prefix, prefix_str);
-
-			printf("\n\troute %s/%d\n\t{\n", prefix_str, rinfo->nd_opt_ri_prefix_len);
+			if (optlen == 8) {
+				printf("\n\troute ::/0\n\t{\n");
+			}
+			else {
+				struct in6_addr addr;
+				memset(&addr, 0, sizeof(addr));
+				memcpy(&addr, &rinfo->nd_opt_ri_prefix, 8);
+				print_addr(&addr, prefix_str);
+				printf("\n\troute %s/%d\n\t{\n", prefix_str, rinfo->nd_opt_ri_prefix_len);
+			}
 
 			if (!edefs || (((radvert->nd_ra_flags_reserved & 0x18) >> 3) & 0xff) != DFLT_AdvRoutePreference) {
 				printf("\t\tAdvRoutePreference ");
